import React, { useReducer, useState } from 'react';
import { Input, Tree, Table, Button, Form, DatePicker, Divider, Select, Space, message } from 'antd';
import { PageContainer } from '@ant-design/pro-components';
import { useRequest, useModel, useRef } from '@umijs/max';
import { queryDirCreate, queryDirList, queryFileList } from '../../services/file';
import { FolderOpenOutlined, PlusCircleOutlined, PlusOutlined } from '@ant-design/icons';
import AddFileModal from './components/model';

const temp = [
  {
    id: 999,
    dir_name: '受控文件',
    children: [
      // { id: '1-1', dir_name: '文件夹1' },
      // {
      //   id: '1-2',
      //   dir_name: '文件夹2',
      //   children: [{ id: '1-2-1', dir_name: '文件夹1' }],
      // },
    ],
  },
  {
    id: 998,
    dir_name: '部门文件',
    children: [
      // { id: '2-1', dir_name: '文件夹1' },
      // { id: '2-2', dir_name: '文件夹2' },
      // { id: '2-3', dir_name: '文件夹3' },
    ],
  },
];

const tempData = [
  { name: '文件', upload_user: '管理员', upload_time: '2023-04-08 11:00:00' },
];

const { DirectoryTree } = Tree;
const { Search } = Input;
const { RangePicker } = DatePicker;

function FileManagement(props) {
  const [form] = Form.useForm();
  const {user} = useModel('userInfo')
  const [treeData, setTreeData] = useState(temp)
  const [visible, setVisible] = useState(false);
  const [id, setId] = useState()

  const {  } = useRequest((data) => queryDirList(data), {
    onSuccess: (data) => {
      console.log(data) 
      const result = [...temp];
      result[0].children = data.limit_list;
      result[1] = data.list[0];
      setTreeData(result)
      console.log(result)
    }
  })
  const { data, loading, run } = useRequest((data) => queryFileList(data), {
    manual: true,
  })
  
  const { loading:createLoading, run:RunCreate } = useRequest((data) => queryDirCreate(data), {
    manual: true,
    onSuccess: () => {
      message.success('创建成功')
    },
    onError: () => {
      message.success('创建失败')
    },
  })


  const [expandedKeys, setExpandedKeys] = useState([]);
  const [searchValue, setSearchValue] = useState('');

  const columns = [
    { title: '文档名称', dataIndex: 'file_name' },
    { title: '上传人员', dataIndex: 'user_name' },
    { title: '上传时间', dataIndex: 'create_time' },
    {
      title: '操作',
      render: (_, record) => (
        <>
          <a>下载</a>
          <Divider type="vertical" />
          <a>删除</a>
          <a onClick={()=>{}}>申请权限</a>
        </>
      ),
    },
  ];

  // 搜索文件夹树
  const onSearchDirectory = (value, nodes = temp) => {
    const expandedKeys = getExpandedKeys(nodes, value);
    setExpandedKeys(expandedKeys);
    setSearchValue(value);
  };

  // 根据搜索值(value)获取key列表
  const getExpandedKeys = (nodes, value) => {
    if (!value) return [];
    let result = [];
    nodes.forEach((node) => {
      if (node.title.includes(value)) {
        result.push(node.key);
      }
      if (node.children) {
        let getChildren = getExpandedKeys(node.children, value);
        if (getChildren.length != 0)
          result = [...result, node.key, ...getChildren];
      }
    });
    return result;
  };

  const onExpand = (expandedKeys) => {
    setExpandedKeys(expandedKeys);
  };

  const filterTreeNode = (node) =>
    searchValue.length > 0 ? node.title.includes(searchValue) : false;

  const onSearch = () => {
    form
      .validateFields()
      .then((values) => {
        console.log(values);
      })
      .catch((err) => {
        return;
      });
  };

  const handlerSelect = (SelectKeys, e) => {
    run({dir_id: SelectKeys[0]})
    console.log(SelectKeys, e)
  }

  return (
    <PageContainer>
      <div style={{ display: 'flex', justifyContent: 'space-between' }}>
        <div style={{ height: '100%', width: '30%' }}>
          <Search onSearch={(value, _) => onSearchDirectory(value)} />
          <DirectoryTree
            expandedKeys={expandedKeys}
            onExpand={onExpand}
            treeData={treeData}
            onSelect={handlerSelect}
            fieldNames={{key:'id', title:'dir_name', children:'children'}}
            filterTreeNode={filterTreeNode}
            titleRender={(item) => {
              return item.dir_name == '部门文件' ? <Space><span>{item.dir_name}</span><Button shape="circle" icon={<PlusOutlined />} onClick={() => {setId(item.id) ; setVisible(true)}}/></Space>
      : <span>{ item.dir_name}</span>}}
          />
        </div>
        <div style={{ height: '100%', width: 'calc(70% - 20px)' }}>
          <Form layout="inline" form={form}>
            <Form.Item name="date">
              <RangePicker />
            </Form.Item>
            <Form.Item name="name">
              <Input />
            </Form.Item>
            <Form.Item>
              <Button type="primary" onClick={onSearch}>
                查询
              </Button>
            </Form.Item>
            <Form.Item>
              <Button type="primary">上传</Button>
            </Form.Item>
          </Form>
          <Table columns={columns} dataSource={data?.list} loading={loading} />
        </div>
      </div>
      <AddFileModal id={id} visible={visible} handleOk={(value) => { RunCreate({...value, user_name:user?.CName}) }} handleCancel={ ()=>setVisible(false)} />
    </PageContainer>
  );
}

export default FileManagement;
